@@ -520,9 +520,7 @@ impl AlignedVec {
 
     /// Converts the vector into `Vec<u8>`.
     ///
-    /// This will preserve the alignment guarantees provided by `AlignedVec` until the vector is
-    /// modified. This will not drop any excess capacity, unlike
-    /// [`into_boxed_slice()`](AlignedVec::into_boxed_slice()).
+    /// This method reallocates and copies the underlying bytes. Any excess capacity is dropped.
     ///
     /// # Examples
     /// ```
@@ -535,27 +533,9 @@ impl AlignedVec {
     /// assert_eq!(vec.len(), 3);
     /// assert_eq!(vec.as_slice(), &[1, 2, 3]);
     /// ```
-    ///
-    /// Any excess capacity is preserved:
-    ///
-    /// ```
-    /// use rkyv::AlignedVec;
-    ///
-    /// let mut vec = AlignedVec::with_capacity(10);
-    /// vec.extend_from_slice(&[1, 2, 3]);
-    ///
-    /// assert_eq!(vec.capacity(), 10);
-    /// let vec = vec.into_vec();
-    /// assert_eq!(vec.len(), 3);
-    /// assert_eq!(vec.capacity(), 10);
-    /// ```
     #[inline]
     pub fn into_vec(self) -> Vec<u8> {
-        unsafe {
-            let result = Vec::from_raw_parts(self.ptr.as_ptr(), self.len, self.cap);
-            core::mem::forget(self);
-            result
-        }
+        Vec::from(self.as_ref())
     }
 }
 
